pub enum CanonicalLanguageIdentifierError {
Invalid {
name: String,
source: LanguageIdentifierError,
},
NonCanonical {
name: String,
canonical: String,
},
}Expand description
Errors returned when parsing a language identifier that must already be canonicalized.
Variants
Invalid
The identifier could not be parsed as a BCP-47 language identifier.
Fields

source: LanguageIdentifierErrorThe parsing error produced by unic-langid.
NonCanonical
The identifier parsed successfully but was not written in canonical form.