Shared runtime-safe types and helpers for the es-fluent ecosystem.
Re-exports
pub use error::EsFluentError;pub use error::EsFluentResult;pub use language::CanonicalLanguageIdentifierError;pub use language::parse_canonical_language_identifier;pub use path_utils::parse_language_entry;pub use path_utils::validate_assets_dir;
Modules
- error
- Common error types shared across the es-fluent ecosystem.
- language
- Shared language-identifier parsing helpers.
- meta
- This module provides types for representing the kind of a type.
- namer
- This module provides types for naming Fluent keys and documentation.
- namespace
- Shared namespace rules used by derive parsing and runtime registration.
- path_
utils - Common path utilities for the es-fluent ecosystem.
- registry
- This module provides types for representing FTL variants and type information.