pub enum NamespaceRule {
Literal(Cow<'static, str>),
File,
FileRelative,
Folder,
FolderRelative,
}Expand description
Namespace selection rules for FTL file output.
Variants
Literal(Cow<'static, str>)
A literal namespace string.
File
Use the source file name (stem only) as the namespace.
FileRelative
Use the file path relative to the crate root as the namespace.
Folder
Use the source file parent folder name as the namespace.
FolderRelative
Use the source file parent folder path relative to crate root as the namespace.
Implementations